/* ===evalU.c===
 * 
 * evaluates U(x,z,u,v) from hep-ph/0501132
 *
 * takes the following arguments
 *
 *   x, z, u, v squared masses
 *   s momentum squared
 *   qq renormalisation scale squared
 *
 * prints the value of U(x,z,u,v) to stdout
 *
 */

#include <stdio.h>
#include "tsil.h"

long double strtold( const char *, char** );

int main( int argc, char *argv[] )
{
  TSIL_DATA foo;
  TSIL_REAL x, z, u, v;
  TSIL_REAL s, qq;
  TSIL_COMPLEX Uxzuv;
  if( argc != 7 )
    TSIL_Error( "EvalU", 
                "Need 6 arguments: m1^2, m2^2, m3^2, m4^2, s, mu^2", 1);

  x = (TSIL_REAL) strtold( argv[1], (char **) NULL );
  z = (TSIL_REAL) strtold( argv[2], (char **) NULL );
  u = (TSIL_REAL) strtold( argv[3], (char **) NULL );
  v = (TSIL_REAL) strtold( argv[4], (char **) NULL );

  s = (TSIL_REAL) strtold( argv[5], (char **) NULL );
  qq = (TSIL_REAL) strtold( argv[6], (char **) NULL );

  TSIL_SetParametersSTU( &foo, x, z, u, v, qq );
  TSIL_Evaluate( &foo, s );

  Uxzuv = TSIL_GetFunction( &foo, "Uxzuv" );

  printf( "%lf + %lf I\n", (double) creal(Uxzuv), cimag(Uxzuv) );

  return 0;
}
